CCL: user_pz_info Struct Reference

CCL

Data Fields
user_pz_info Struct Reference

`#include <ccl_lsst_specs.h>`

## Data Fields
double(* | your_pz_func )(double, double, void *, int *)
void * | your_pz_params

## Detailed Description

A user-defined P(z) function. This is a user-defined P(z) function, with a void* field to contain the parameters to that function.

## Field Documentation

## ◆ your_pz_func

double(* user_pz_info::your_pz_func) (double, double, void *, int *)

## ◆ your_pz_params

void* user_pz_info::your_pz_params

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_lsst_specs.h